-- Creates the base tables for project-tracker. pt-workflow-create.sql
-- should be loaded next
-- project-tracker/sql/pt-core-create.sql
-- @author Nobuko Asakai nasakai@arsdigita.com
--
-- @creation-date 2000-12-11
--
-- @cvs-id $Id: pt-core-create.sql,v 1.2 2001/04/18 00:35:29 nasakai Exp $
--


----------------------------------
-- KNOWLEDGE LEVEL OBJECTS
----------------------------------

declare
v_attribute_id acs_attributes.attribute_id%TYPE;
begin
    acs_object_type.create_type(
        object_type	 => 'pt_task',
	pretty_name	 => 'Task',
	pretty_plural    => 'Tasks',
	table_name	 => 'PT_TASKS',
	id_column	 => 'task_id',
	package_name	 => 'pt_task',
	name_method	 => 'pt_task.name',
	supertype	 => 'acs_object'
    );

    v_attribute_id := acs_attribute.create_attribute (
        object_type     => 'pt_task',
	attribute_name  => 'task_id',
	datatype	=> 'integer',
	pretty_name	=> 'Task ID',
	pretty_plural	=> 'Task IDs'
    );

    v_attribute_id := acs_attribute.create_attribute (
        object_type     => 'pt_task',
	attribute_name  => 'name',
	datatype	=> 'string',
	pretty_name	=> 'Task Name',
	pretty_plural	=> 'Task Names'
    );

    v_attribute_id := acs_attribute.create_attribute (
        object_type     => 'pt_task',
	attribute_name  => 'description',
	datatype	=> 'string',
	pretty_name	=> 'Task Description',
	pretty_plural	=> 'Task Descriptions'
    );
    v_attribute_id := acs_attribute.create_attribute (
        object_type     => 'pt_task',
	attribute_name  => 'estimated_days',
	datatype	=> 'number',
	pretty_name	=> 'Estimated Days',
	pretty_plural	=> 'Estimated Days'
    );

    v_attribute_id := acs_attribute.create_attribute (
        object_type     => 'pt_task',
	attribute_name  => 'actual_days',
	datatype	=> 'number',
	pretty_name	=> 'Actual Days',
	pretty_plural	=> 'Actual Days'
    );

    v_attribute_id := acs_attribute.create_attribute (
        object_type     => 'pt_task',
	attribute_name  => 'deadline',
	datatype	=> 'date',
	pretty_name	=> 'Task Deadline',
	pretty_plural	=> 'Task Deadlines'
    );

    v_attribute_id := acs_attribute.create_attribute (
        object_type     => 'pt_task',
	attribute_name  => 'leaf_p',
	datatype	=> 'string',
	pretty_name	=> 'Task leaf status',
	pretty_plural	=> 'Task leaf status'
    );

   v_attribute_id := acs_attribute.create_attribute (
        object_type     => 'pt_task',
	attribute_name  => 'priority',
	datatype	=> 'number',
	pretty_name	=> 'Task priority',
	pretty_plural	=> 'Task priorities'
    );
end;
/
show errors

----------------------------------
-- OPERATIONAL LEVEL
----------------------------------

-- Table added on April 09, 2001 nasakai@arsdigita.com

create sequence pt_priority_seq start with 1;

create table pt_priorities (
    priority_id		  number 
			  constraint pt_pri_priority_id_pk
			  primary key,
    package_id		  constraint pt_pri_package_id_fk	
			  references apm_packages(package_id),
    value		  integer
			  constraint pt_pri_value_nn
			  not null,
    name		  varchar2(100)
			  constraint pt_pri_name_nn	
			  not null,
    constraint pt_pri_pkg_val_un unique(package_id, value),
    constraint pt_pri_pkg_name_un unique(package_id, name)
);


-- We are not using ACS Objects so we do not use the standard procedure names

-- We also want to insert some default values on initialization. This
-- will be done in pt_project.new procedure


create table pt_tasks (
    task_id 		constraint pt_tasks_task_id_pk
			primary key
			constraint pt_tasks_task_id_acs_object_fk
			references acs_objects  on delete cascade,
    parent_id 		constraint pt_tasks_parent_id_fk
			references pt_tasks(task_id)  on delete cascade,
    constraint pt_task_parent_un
     unique(task_id, parent_id),                          			
    name		varchar2(200)
			constraint pt_task_name_nn
			not null,	   
    description		varchar2(4000),
    estimated_days	number,
    actual_days		number,
    deadline		date,
    leaf_p		char(1) default 't' 
                        constraint pt_tasks_leaf_ck 
			check (leaf_p in ('t', 'f'))
			constraint pt_task_leaf_p_nn
			not null,	    
    dropped_p		char(1) default 'f' 
                        constraint pt_tasks_dropped_p_ck 
			check (dropped_p in ('t', 'f'))
			constraint pt_task_dropped_p_nn
			not null,	   
    html_p		char(1) default 'f' 
                        constraint pt_tasks_html_p
			check (html_p in ('t', 'f'))
			constraint pt_task_html_p_nn
			not null,
    priority		integer 
			constraint 
			pt_tasks_priority_fk
			references pt_priorities(priority_id) on delete set null
);

-- Index for columns that references other tables to avoid locking

create index pt_parent_idx on pt_tasks(parent_id, task_id);
create index pt_dropped_p_idex on pt_tasks(dropped_p);
create index pt_leaf_p_idex on pt_tasks(leaf_p);


comment on column pt_tasks.estimated_days is '
The information here is should be copied over to wf_cases. However,
the unit here is days, and the unit in wf is minutes.
';

comment on column pt_tasks.priority is ' The name - value pair is
stored in pt_priorities table. This is an optional paramter.  ' ;

/* 
ACS Rels to indicate which package instance the root node maps
to. This is nice because it makes it easy to add project wide
attributes. This is a one to one mapping. 
*/

begin
    acs_rel_type.create_role ('root_task');

    acs_rel_type.create_role ('package_instance');
    -- This is the package_id from apm_packages table

    acs_rel_type.create_type (
        rel_type	     => 'pt_project_rel',			 
	pretty_name	     => 'Project Tracker Prject',
	pretty_plural	     => 'Project Tracker Prject', 
	package_name	     => 'pt_project',
	table_name	     => 'pt_projects',
	id_column	     => 'project_id',
	object_type_one	     => 'pt_task',
	role_one	     => 'root_task',
	min_n_rels_one	     => 0,
	max_n_rels_one	     => null,
	object_type_two	     => 'acs_object',
	role_two	     => 'package_instance',
	min_n_rels_two	     => 0,
	max_n_rels_two	     => null
    );  
end;
/
show errors

create table pt_projects (
    project_id	        constraint pt_projects_id_fk
			references acs_rels(rel_id)
			constraint pt_project_rel_id_pk
			primary key
);
		

comment on table pt_projects is '
Each Project-Tracker instance is a project. This relationship is
enforced by mapping the root task to the package instance
object. '


/* This view joins wf_cases with theparties data model to figure out
 who is assigned to a case. It should contain one row per (user x case)
 Similar to wf_user_tasks view in wf core datamodel
*/

-- Creating an expanded view for workflow_case_assignments
-- All we want to know is whether the task belongs to a user

create or replace view pt_case_assignments as
select distinct wca.case_id,
       u.user_id 
from wf_case_assignments wca, 
     users u, 
     party_approved_member_map m
where workflow_key = 'pt_task_wf'
and m.party_id = wca.party_id
and u.user_id = m.member_id;









