--
-- project-tracker/sql/pt-drop.sql
-- @author Nobuko Asakai nasakai@arsdigita.com
--
-- @creation-date 2000-12-21
--
-- @cvs-id $Id: pt-core-drop.sql,v 1.3 2001/04/19 15:34:23 nasakai Exp $
--

-- @@pt-workflow-drop

-- delete all the roots

set serveroutput on size 1000000 format wrapped;


declare
    cursor project_cursor
    is select project_id from pt_projects;
    
    project_row project_cursor%ROWTYPE;
    v_package_id acs_objects.object_id%TYPE;

    cursor permission_cursor(v_object_id acs_objects.object_id%TYPE)
    is 
    select grantee_id, privilege
    from acs_permissions 
    where object_id = v_object_id;
    
    permission_row permission_cursor%ROWTYPE;
begin
   for project_row in project_cursor 
   loop
       delete from pt_projects
       where project_id = project_row.project_id;

       select object_id_two into v_package_id
       from acs_rels
       where rel_id = project_row.project_id;
       
       -- Get rid of the priorities
       delete from pt_priorities
       where package_id = v_package_id;

       
       acs_rel.delete(project_row.project_id);
       
       -- Clean up the permissions
       -- well this is a lot of work isn't it
       for permission_row in permission_cursor(project_row.project_id)
       loop
	   acs_permission.revoke_permission(
	        object_id  => project_row.project_id,
		grantee_id => permission_row.grantee_id,
		privilege  => permission_row.privilege
	   );
       end loop;
   end loop;
end;
/
show errors


drop table pt_projects;

-- Now drop the rels
begin
   acs_rel_type.drop_type ('pt_project_rel');

   acs_rel_type.drop_role ('root_task');

   acs_rel_type.drop_role ('package_instance');
end;
/
show errors


declare
    cursor root_cursor is
    select task_id from pt_tasks where parent_id is null;

    root_row root_cursor%ROWTYPE;

    cursor task_cursor(v_root pt_tasks.task_id%TYPE) is
    select task_id from pt_tasks
    start with task_id = v_root
    connect by parent_id = prior task_id
    order by level desc;

    task_row task_cursor%ROWTYPE;


begin
    for root_row in root_cursor
    loop
	for task_row in task_cursor(root_row.task_id) loop
	    delete from pt_tasks where task_id = task_row.task_id;
	    
	    acs_object.delete(task_row.task_id);

	    -- We don't call the wf_case.delete here because we assume
            -- that this is taken care of already.
	end loop;
    end loop;
end;
/
show errors

-- We don't need to delete the general comments because it has on delete cascade

-- Task table

drop index pt_parent_idx;
drop index pt_dropped_p_idex;
drop index pt_leaf_p_idex;

drop table pt_tasks;

drop sequence pt_priority_seq;
drop table pt_priorities;

-- drop table pt_states;

begin
   acs_object_type.drop_type (
       object_type	     => 'pt_task',
       cascade_p	     => 't'
   );
end;
/
show errors









