--
-- project-tracker/sql/pt-priorty-package.sql
-- 
-- Prioty information for Project Tracker. New feature added on April 09, 2001
--
-- @author Nobuko Asakai nasakai@arsdigita.com
--
-- @creation-date 2000-04-09
--
-- @cvs-id $Id: pt-priority-package.sql,v 1.1.1.1 2001/04/10 21:00:11 nasakai Exp $


create or replace package pt_priority
is

	-- Create a new priority option, there's no real need to
	-- return a value, but I'm going to do it anyway to follow convention

	function option_new   (
	    priority_id	   in pt_priorities.priority_id%TYPE default null,
	    package_id	   in pt_priorities.package_id%TYPE,
	    value	   in pt_priorities.value%TYPE,
	    name	   in pt_priorities.name%TYPE
	) return pt_priorities.priority_id%TYPE;
	

	-- Delete the priority option, given priority_id. We overload
        -- these procedures 

	procedure option_drop (
	    priority_id	   in pt_priorities.priority_id%TYPE
	);
	
	-- Delete the priority option given package_id and value
	procedure option_drop (
	    package_id	   in pt_priorities.package_id%TYPE,
	    value	   in pt_priorities.value%TYPE
	);
	

	function option_name (
	    priority_id	   in pt_priorities.priority_id%TYPE
	) return pt_priorities.name%TYPE;
	
	-- Return the name of the priority option given package_id and value
	-- This is different from the standard name funtion
	function option_name (
	    package_id	   in pt_priorities.package_id%TYPE,
	    value	   in pt_priorities.value%TYPE
	) return pt_priorities.name%TYPE;

	-- Returns 't' if option_id is valid for the package instance
	function option_valid (
	     priority_id   in pt_priorities.priority_id%TYPE,
	     package_id	   in pt_priorities.package_id%TYPE
	) return char;

end pt_priority;
/
show errors


create or replace package body pt_priority
is
	function option_new   (
	    priority_id	   in pt_priorities.priority_id%TYPE default null,
	    package_id	   in pt_priorities.package_id%TYPE,
	    value	   in pt_priorities.value%TYPE,
	    name	   in pt_priorities.name%TYPE
	) return pt_priorities.priority_id%TYPE
	is
	v_priority_id pt_priorities.priority_id%TYPE;
	begin

	    if package_id is null or name is null or value is null then
                raise_application_error(-2000, 'Arguments, with the exception of priority_id, cannot be null');
	    end if;	   
	
	    if priority_id is null then
	        select pt_priority_seq.nextval into v_priority_id from dual;
            else
	        v_priority_id := option_new.priority_id;
	    end if;

	    insert into pt_priorities
	       (priority_id,  package_id, value, name)
	    values
	       (v_priority_id, option_new.package_id, 
	       option_new.value, option_new.name);

	    return v_priority_id;
	end option_new;
	

	-- Delete the priority option, given package_id and value

	procedure option_drop (
	    priority_id	   in pt_priorities.priority_id%TYPE
	) 
	is
	begin

	    delete from pt_priorities
	    where priority_id = option_drop.priority_id;

	end option_drop;
	
	procedure option_drop (
	    package_id	   in pt_priorities.package_id%TYPE,
	    value	   in pt_priorities.value%TYPE
	)
	is
	begin
	
	    if option_drop.package_id is null or option_drop.value is null then
                raise_application_error(-2000, 'Arguments cannot be null');
	    end if;	   

	    delete from pt_priorities
	    where package_id = option_drop.package_id
	    and   value	     = option_drop.value;

	end option_drop;

	function option_name (
	    priority_id	   in pt_priorities.priority_id%TYPE
	) return pt_priorities.name%TYPE
	is	
	    v_name pt_priorities.name%TYPE;
	begin  
	    -- Maybe make a cursor so it will return an application error?

	    select name into v_name
	    from pt_priorities
	    where priority_id = option_name.priority_id;
		  
	    return v_name;
	end option_name;

	function option_name (
	    package_id	   in pt_priorities.package_id%TYPE,
	    value	   in pt_priorities.value%TYPE
	) return pt_priorities.name%TYPE
	is
	    v_name pt_priorities.name%TYPE;
	begin

	    if option_name.package_id is null or option_name.value is null then
                raise_application_error(-2000, 'Arguments cannot be null');
	    end if;	   

	    select name  into v_name
	    from pt_priorities
	    where package_id  = option_name.package_id
	    and	  value	      = option_name.value;
		  
	    return v_name;
	end option_name;

	function option_valid (
	     priority_id   in pt_priorities.priority_id%TYPE,
	     package_id	   in pt_priorities.package_id%TYPE
	) return char
	is
	     v_boolean char(1);
	begin

	     select decode(count(*), 0, 'f', 't') into v_boolean
	     from pt_priorities
	     where package_id = option_valid.package_id
	     and priority_id = option_valid.priority_id;

	     return v_boolean;
	end option_valid;

end pt_priority;
/
show errors

