--   Creates the project package for project-tracker Requires pt_task
--   package. Unit test is in tests/pt-project-test.sql which requires
--   utPL/SQL

--
--   @file-name project-tracker/sql/pt-project-package.sql

--   @author Nobuko Asakai nasakai@arsdigita.com
  
--   @cvs-id $Id: pt-project-package.sql,v 1.1.1.1 2001/04/10 21:00:11 nasakai Exp $
  
-- This package is the wrapper for the pt_projects table and the related acs_rels

-- The need to create a new workflow case for parent tasks turned
-- leaf tasks makes the signatures for any kind of moving
-- messy. The other option is to ensure that the proper procedure
-- is called in tcl. nasakai@arsdigita.com Feb 12, 2000

-- Anything that specifically requires root, package, or project

create or replace package pt_project
as
    -- Returns the name of the root task.
    function name (
	task_id     in pt_tasks.task_id%TYPE
    ) return pt_tasks.name%TYPE;

    -- Creates three options for priority, high, medium, low
    procedure create_priority_options (
        package_id   in acs_objects.object_id%TYPE
    );

    function new (
        rel_type        in acs_rels.rel_type%TYPE default 'pt_project_rel',
	project_id	in pt_projects.project_id%TYPE default null,
        root_id		in pt_tasks.task_id%TYPE default null,
	package_id	in acs_objects.object_id%TYPE,
	name		in pt_tasks.name%TYPE,
	description	in pt_tasks.description%TYPE,
	html_p		in pt_tasks.html_p%TYPE default 't',
	estimated_days	in pt_tasks.estimated_days%TYPE default null,
	deadline	in pt_tasks.deadline%TYPE default null,
	creation_user   in acs_objects.creation_user%TYPE default null,
	creation_ip     in acs_objects.creation_ip%TYPE default null,
	context_id	in acs_objects.context_id%TYPE
    ) return pt_projects.project_id%TYPE;

    procedure delete (
        project_id	in pt_projects.project_id%TYPE
    );

    -- NOTE: I don't like having package_id as a parameter in these
    -- procedures. It would be better to have project_id as a
    -- parameter, however, it would be more expensive.  
    -- nasakai@arsdigita.com FEB 08

    -- Returns the root_id for the project
    -- if drop_p is t, returns the root_id of the shadow project
    function get_root (
        package_id    in acs_objects.object_id%TYPE
    ) return pt_tasks.task_id%TYPE;

    function get_project (
        package_id    in acs_objects.object_id%TYPE
    ) return pt_projects.project_id%TYPE;
    
    function get_package (
        task_id	      in pt_tasks.task_id%TYPE
    ) return acs_objects.object_id%TYPE;


    -- Returns t if there's only one level two task, this function is
    -- for figuring out the move option. drop_p to indicate wheather
    -- working with the real project or the drop bucket

    function one_level_two (
        root_id		   in pt_tasks.task_id%TYPE
    ) return pt_tasks.task_id%TYPE;

    function max_level (
        root_id	       in pt_tasks.task_id%TYPE
    ) return number;

    -- Returns 1 if the task belongs to the instance and 0 if not
    function task_valid_p (
        package_id in acs_objects.object_id%TYPE,
	task_id	   in pt_tasks.task_id%TYPE
    ) return number;


end pt_project;
/
show errors

create or replace package body pt_project
as
    /* Public */
    function name (
	task_id     in pt_tasks.task_id%TYPE
    ) return pt_tasks.name%TYPE
    is
        v_name pt_tasks.name%TYPE;
    begin
        -- Going up the tree
        select name into v_name
	from pt_tasks
	where parent_id is null
	start with task_id = name.task_id
	connect by  task_id = prior parent_id;
	return v_name;
    end name;
    
    function get_root (
        package_id    in acs_objects.object_id%TYPE
    ) return pt_tasks.task_id%TYPE
    is 
    v_task_id pt_tasks.task_id%TYPE;
    begin
         select object_id_one into v_task_id 
	 from acs_rels 
	 where object_id_two = get_root.package_id
	 and rel_type = 'pt_project_rel';
	 
	 return v_task_id;
    end get_root;

    function get_project (
        package_id    in acs_objects.object_id%TYPE
    ) return pt_projects.project_id%TYPE
    is
    v_project_id pt_projects.project_id%TYPE;
    begin
        select rel_id into v_project_id
        from acs_rels 
	where object_id_two = get_project.package_id
	and rel_type = 'pt_project_rel';

	return v_project_id;
    end get_project;

    -- Drop a task from a project (not delete)

    function one_level_two (
        root_id		   in pt_tasks.task_id%TYPE
    ) return pt_tasks.task_id%TYPE
    is
    v_only_one char;
    v_task_id number default null;
    begin
        -- This is a nasty function...
    
        select decode(count(*), 1, 't', 'f') into v_only_one
        from pt_tasks
	where level = 2
	and dropped_p = 'f'
	start with task_id =  root_id
	connect by parent_id = prior task_id;

	if v_only_one = 't' 
	then
	     select task_id into v_task_id
	     from pt_tasks
	     where level = 2
	     and dropped_p = 'f'	
	     start with task_id =  root_id
	     connect by parent_id = prior task_id;

	     return v_task_id;
	end if;

	return v_task_id;
    end one_level_two;

    function max_level (
        root_id	       in pt_tasks.task_id%TYPE
    ) return number
    is 
        v_max_level number;
    begin
        select max(level) into v_max_level
	from pt_tasks
	start with task_id = root_id
	connect by parent_id = prior task_id;
	
	return v_max_level;
    end max_level;

    procedure create_priority_options (
        package_id   in acs_objects.object_id%TYPE
    )
    is
    v_priority_id pt_priorities.priority_id%TYPE;
    begin
        v_priority_id :=  pt_priority.option_new (	
	     package_id => create_priority_options.package_id,
	     value	=> 1,
	     name	=> 'Low'
	);

        v_priority_id :=  pt_priority.option_new (	
	     package_id => create_priority_options.package_id,
	     value	=> 2,
	     name	=> 'Medium'
	);

        v_priority_id :=  pt_priority.option_new (	
	     package_id => create_priority_options.package_id,
	     value	=> 3,
	     name	=> 'High'
	);

    end create_priority_options;

    function new (
        rel_type        in acs_rels.rel_type%TYPE default 'pt_project_rel',
	project_id	in pt_projects.project_id%TYPE default null,
        root_id		in pt_tasks.task_id%TYPE default null,
	package_id	in acs_objects.object_id%TYPE,
	name		in pt_tasks.name%TYPE,
	description	in pt_tasks.description%TYPE,
	html_p		in pt_tasks.html_p%TYPE default 't',
	estimated_days	in pt_tasks.estimated_days%TYPE default null,
	deadline	in pt_tasks.deadline%TYPE default null,
	creation_user   in acs_objects.creation_user%TYPE default null,
	creation_ip     in acs_objects.creation_ip%TYPE default null,
	context_id	in acs_objects.context_id%TYPE
    ) return pt_projects.project_id%TYPE
    is
    v_project_id	   pt_tasks.task_id%TYPE;
    v_root_id		   pt_tasks.task_id%TYPE;
    begin
	v_root_id := pt_task.new (
	    task_id	    => pt_project.new.root_id,
	    parent_id	    => null,
	    name	    => pt_project.new.name,
	    description	    => pt_project.new.description,
	    html_p	    => pt_project.new.html_p,
	    deadline	    => pt_project.new.deadline,
	    estimated_days  => pt_project.new.estimated_days,
	    context_id	    => pt_project.new.context_id
	);

        v_project_id := acs_rel.new (
	    rel_id	    => project_id,
	    rel_type	    => rel_type,
	    object_id_one   => v_root_id,
	    object_id_two   => package_id,
	    context_id	    => context_id,
	    creation_user   => creation_user,
	    creation_ip	    => creation_ip
        );

        insert into pt_projects
            (project_id)
        values
	    (v_project_id);
	    
        -- Create some default priority options
	pt_project.create_priority_options (
	    package_id => pt_project.new.package_id
	);

	return v_project_id;
    end new;

    procedure delete (
        project_id	in pt_projects.project_id%TYPE
    )
    is
    v_root pt_tasks.task_id%TYPE;
    v_package_id acs_objects.object_id%TYPE;
    begin
    
	select object_id_one, object_id_two into v_root, v_package_id
	from acs_rels
	where rel_id = pt_project.delete.project_id;

	delete from pt_projects
	where project_id = pt_project.delete.project_id;

	delete from pt_priorities
	where package_id = v_package_id;

	acs_rel.delete (pt_project.delete.project_id);

       -- Deletes the root and all the cases associated with it	
	pt_task.delete (
	    task_id       => v_root
	);
       
    end delete;

    function task_valid_p (
        package_id in acs_objects.object_id%TYPE,
	task_id	   in pt_tasks.task_id%TYPE
    ) return number
    is
	v_valid_p  number;
    begin
	   select count(*) into v_valid_p
	   from pt_tasks
	   where task_id = task_valid_p.task_id
	   start with task_id = pt_project.get_root(task_valid_p.package_id)
	   connect by parent_id = prior task_id;

	   return v_valid_p;
    end task_valid_p;

    function get_package (
        task_id	      in pt_tasks.task_id%TYPE
    ) return acs_objects.object_id%TYPE
    is
	v_package_id acs_objects.object_id%TYPE;
    begin

        select object_id_two into v_package_id
	from acs_rels
	where object_id_one = pt_task.get_task_origin(get_package.task_id)
        and rel_type = 'pt_project_rel';

	return v_package_id;
    end get_package;

end pt_project;
/
show errors











