/* project-tracker/sql/pt-workflow-create.sql */
-- Creates the project-tracker workflow
-- @author Nobuko Asakai nasakai@arsdigita.com
--
-- @creation-date 2000-12-11
--
-- @cvs-id $Id: pt-workflow-create.sql,v 1.3 2001/04/18 00:35:29 nasakai Exp $
--


create table pt_task_cases (
  case_id 		constraint pt_task_cases_case_fk
			references wf_cases on delete cascade
);

declare
    v_workflow_key varchar2(40);
begin
    v_workflow_key := workflow.create_workflow(
	workflow_key	=> 'pt_task_wf', 
	pretty_name	=> 'Task for a project', 
	pretty_plural	=> 'Tasks for a project',  
	description	=> 'Workflow for project-tracker tasks', 
	table_name	=> 'PT_TASK_CASES'
    );


    workflow.add_place (
        workflow_key   => v_workflow_key,
	place_key      => 'start',
	place_name     => 'Needs to be completed',
	sort_order     => 1
    );

    workflow.add_place (
        workflow_key   => v_workflow_key,
	place_key      => 'end',
	place_name     => 'Task complete',
	sort_order     => 1
    );

    --- Transitions

    workflow.add_transition (
        workflow_key	    => v_workflow_key,
        transition_key	    => 'complete',
	transition_name	    => 'Complete Task',
	sort_order	    => 1,
	trigger_type	    => 'user'
    );

end;
/
show errors

-- Add guards and such here

declare
    v_workflow_key constant varchar2(40) := 'pt_task_wf';
begin

    workflow.add_arc (
        workflow_key		=> v_workflow_key,
        transition_key          => 'complete',
        place_key               => 'start',
        direction               => 'in'
   );

    workflow.add_arc (
        workflow_key		=> v_workflow_key,
        transition_key          => 'complete',
        place_key               => 'end',
        direction               => 'out'
   );

end;
/
show errors

declare
    v_attribute_id acs_attributes.attribute_id%TYPE;
begin
    v_attribute_id := workflow.create_attribute(
	workflow_key   => 'pt_task_wf',
	attribute_name => 'actual_days',
	datatype       => 'number',
	pretty_name    => 'Actual days spent<br>
	                   <font size=-1>(must be a number)</font>',
	default_value  => 'f'
    );

    insert into wf_transition_attribute_map
        (workflow_key, transition_key, attribute_id, sort_order) 
    values
        ('pt_task_wf', 'complete', v_attribute_id, 1);
end;
/
show errors

-- Add some callbacks here

-- We don't have an assignment callback because assignment is done
-- directly in wf_case_assignments

-- We also enforce permissions

-- We used to have get deadline and copy attributes, but it
-- has been decided that we do not like storing duplicate
-- information, however, a new approach is needed if we decide
-- that we want to send late deadline notification

insert into wf_context_transition_info (
     context_key, 
     workflow_key, 
     transition_key, 
     notification_callback,
     notification_custom_arg,
     fire_callback,
     access_privilege -- Copy completion info to pt
) values (
     'default', 
     'pt_task_wf', 
     'complete', 
     'pt_callback.notification',
     'Complete Task',
     'pt_callback.complete_fire',
     'write'
);

insert into wf_context_task_panels (
    context_key, 
    workflow_key, 
    transition_key, 
    sort_key, 
    header, 
    template_url
) values (
  'default',
  'pt_task_wf',
  'complete',
  1,
  'Task Information',
  '/packages/project-tracker/wf-templates/task-info'
);


-- Add assignment callbacks
      







