--
-- project-tracker/sql/upgrade-4.0-4.1.sql
-- 
-- Upgrade script for Project Tracker
--
-- @author Nobuko Asakai nasakai@arsdigita.com
--
-- @creation-date 2000-03-27
--
-- @cvs-id $Id: developer-alpha-upgrade.sql,v 1.1 2001/04/10 22:57:01 nasakai Exp $



-- This file is really just for the version running on developer.arsdigita.com
-- Adding priority
-- April 09, 2001

create index pt_parent_idx on pt_tasks(parent_id, task_id);
create index pt_dropped_p_idex on pt_tasks(dropped_p);
create index pt_leaf_p_idex on pt_tasks(leaf_p);

create sequence pt_priority_seq start with 1;

create table pt_priorities (
    priority_id		  number 
			  constraint pt_pri_priority_id_pk
			  primary key,
    package_id		  constraint pt_pri_package_id_fk	
			  references apm_packages(package_id),
    value		  integer
			  constraint pt_pri_value_nn
			  not null,
    name		  varchar2(100)
			  constraint pt_pri_name_nn	
			  not null,
    constraint pt_pri_pkg_val_un unique(package_id, value),
    constraint pt_pri_pkg_name_un unique(package_id, name)
);

create index pt_pri_pkg_idx on pt_priorities(package_id);

alter table pt_tasks 
      add 
(
      priority integer
      constraint pt_tasks_priority_fk
      references pt_priorities(priority_id) on delete null -- check this
);       

comment on column pt_tasks.priority is '
	The name - value pair is stored in pt_priorities table.
'
;

-- Compile the new/modified packages
@pt-task-package

@pt-priority-package

-- Insert default values during initialization
@@pt-project-package

-- Insert default values for packages that are already working.
declare
	cursor project_cursor
	is
	select object_id_two
	from acs_rels
	where rel_type = 'pt_project_rel';
	
	project_row project_cursor%ROWTYPE;
begin 
      
      for project_row in project_cursor
      loop
          pt_project.create_priority_options (
	      package_id => project_row.object_id_two
	  );
      end loop;
end;
/
show errors

-- Test for creating default values for existing packages

declare
     v_project_count number;
     v_option_count number;	
begin
     select count(*) into v_project_count
     from pt_projects;
     
     select count(unique(package_id)) into v_option_count
     from pt_priorities;
     
     if v_project_count	<> v_option_count then
          raise_application_error(-2000, 'Failed populating pt_priority table');
     end if;
end;
/
show errors

@pt-task-package




