-- /project-tracker/sql/tests/pt-priority-test.sql
-- 
-- Prioty information for Project Tracker. New feature added on April 09, 2001
--
-- @author Nobuko Asakai nasakai@arsdigita.com
--
-- @creation-date 2000-04-09
--
-- @cvs-id $Id: pt-priority-test.sql,v 1.1.1.1 2001/04/10 21:00:12 nasakai Exp $


/* 

   To add the priority opion, I have to:
   - add a priority column to pt_tasks table
   - Create a table that maps priority to package_id and human readable name	
*/

set serveroutput on size 1000000 format wrapped;

create or replace package ut_pt_priority
is
    procedure ut_setup;
    procedure ut_teardown;
    procedure ut_pt_priority;

    procedure option_new;    

    procedure option_name;

    procedure option_drop;

    procedure option_valid;

end ut_pt_priority;
/
show errors


create or replace package body ut_pt_priority
is
    v_package_id pt_priorities.package_id%TYPE;

    function option_count 
    return number
    is
    v_number number;
    begin
       select count(*) into v_number 
       from pt_priorities;
       
       return v_number;
    end;

    procedure ut_setup
    is
    begin
        null;
    end;

    procedure ut_teardown
    is
    v_count number;
    begin
       delete from pt_priorities;

       select count(*) into v_count from pt_priorities;
       
       utAssert.eq (
           msg_in => 'Checking for clean deletion',
	   check_this_in => v_count,
	   against_this_in => 0
       );
    end;

    procedure option_new
    is
    v_priority_id pt_priorities.priority_id%TYPE;
    v_count number;
    begin
    

      -- Without priority_id
      v_priority_id :=  pt_priority.option_new (
          package_id => v_package_id,
	  value	     => 1,
	  name	     => 'ONE'
      );
      
      utAssert.eq (	
          msg_in =>'Checking basic creation',
	  check_this_in => option_count,
	  against_this_in => 1
      );
      
      select pt_priority_seq.nextval into v_priority_id
      from dual;

      -- Without priority_id
      v_priority_id :=  pt_priority.option_new (
          priority_id  => v_priority_id,
          package_id => v_package_id,
	  value	     => 2,
	  name	     => 'two'
      );
      
      utAssert.eq (	
          msg_in =>'Checking basic creation',
	  check_this_in => option_count,
	  against_this_in => 2
      );

    end;    

    procedure option_name
    is
    v_priority_id pt_priorities.priority_id%TYPE;
    v_value	 pt_priorities.value%TYPE;
    begin
       -- This is really dumb
       select priority_id, value into v_priority_id, v_value
       from pt_priorities
       where name = 'ONE';
       
       -- priority_id
       utAssert.eq (
          msg_in => 'name function priority_id',
	  check_this_in => pt_priority.option_name( v_priority_id),
	  against_this_in => 'ONE'
       );
       
       -- package_id and value
       -- priority_id
       utAssert.eq (
          msg_in => 'name function priority_id',
	  check_this_in => pt_priority.option_name (v_package_id,  v_value),
	  against_this_in => 'ONE'
       );

    end;

    procedure option_drop
    is
    v_priority_id pt_priorities.priority_id%TYPE;
    v_value	 pt_priorities.value%TYPE;
    begin
       ut_teardown;
       
       v_priority_id :=  pt_priority.option_new (
          package_id => v_package_id,
	  value	     => 5,
	  name	     => 'drop'
       );

       -- priority_id
       pt_priority.option_drop (v_priority_id);

       utAssert.eq (
           msg_in => 'Dropped one option with just priority_id',
	   check_this_in => option_count,
	   against_this_in => 0
       );

       v_priority_id :=  pt_priority.option_new (
          package_id => v_package_id,
	  value	     => 8,
	  name	     => 'drop'
       );

       pt_priority.option_drop (v_package_id, 8);

       utAssert.eq (
           msg_in => 'Dropped one option with just priority_id',
	   check_this_in => option_count,
	   against_this_in => 0
       );

    end;

    procedure option_valid
    is
    v_priority_id pt_priorities.priority_id%TYPE;
    begin
         ut_teardown;
	 
         v_priority_id :=  pt_priority.option_new (
            package_id       => v_package_id,
	    value	     => 5,
	    name	     => 'drop'
         );
	     
	 utAssert.eq (
	    msg_in => 'Checking valid option',
	    check_this_in => pt_priority.option_valid (
	                         package_id => v_package_id,
				 priority_id => v_priority_id
	                     ),
            against_this_in => 't'			     
	 );

	 -- Invalid priority_id some number
	 utAssert.eq (
	    msg_in => 'Checking invalid option',
	    check_this_in => pt_priority.option_valid (
	                         package_id => v_package_id,
				 priority_id => 10
	                     ),
            against_this_in => 't'			     
	 );
    end;

    procedure ut_pt_priority
    is
    begin
        ut_setup;
	
	ut_teardown;

	dbms_output.put_line ('Testing basic creation');
        option_new;
	
	dbms_output.put_line ('Testing name function overloading');
	option_name;
	
	dbms_output.put_line ('Testing drop procedure overloading');
	option_drop;
    end;

    begin
      -- Grabbing a random package_id to play with
      select package_id into v_package_id
      from apm_packages
      where rownum = 1;
end ut_pt_priority;
/
show errors


exec utplsql.test('pt_priority', recompile_in => false);
