--    Basic creation and deletion test for sql/pt-project-package
--    
--    Requires utPL/SQL and pt_task
--    @author Nobuko Asakai (nasakai@arsdigita.com)
--    @creation-date 01-19-2001
--    @cvs-id $Id: pt-project-test.sql,v 1.1.1.1 2001/04/10 21:00:12 nasakai Exp $


set serveroutput on size 1000000 format wrapped;

create or replace package ut_pt_project 
is
    procedure ut_setup;
        
    procedure ut_teardown;

    procedure new;
    
    procedure name;

    procedure new_with_id;


    -- Container procedure
    procedure ut_pt_project;

end ut_pt_project;
/
show errors

create or replace package body ut_pt_project 
is
    /* Helpers */
    v_task_id pt_tasks.task_id%TYPE;
    v_number number;
    v_count number;
    v_package_id apm_packages.package_id%TYPE;
    v_context_id number;
    
    procedure ut_setup
    is
    begin
       ut_teardown;
    end;
        
    procedure ut_teardown
    is
    cursor project_cursor is
    select project_id from pt_projects;

    project_row project_cursor%ROWTYPE;
    begin
      dbms_output.put_line ('Tearing down... ');

       for project_row in project_cursor 
          loop
	        dbms_output.put_line ('Looping thru projects ');
	         pt_project.delete (
		 project_id => project_row.project_id);
	  end loop;
	 
      select count(*) into v_count from pt_projects; 

      utAssert.eq (
          msg_in          => 'Teardown',
	  check_this_in   => v_count,
	  against_this_in => 0);
      
      select count(*) into v_count from pt_tasks; 

      utAssert.eq (
          msg_in          => 'task teardown',
	  check_this_in   => v_count,
	  against_this_in => 0);
    end;

    procedure new
    is
    v_project_id pt_projects.project_id%TYPE;
    v_name pt_tasks.name%TYPE;
    p_count number;
    begin
    
    v_project_id :=   pt_project.new (
          package_id   => v_package_id,  
          name	       =>  'parent',
	  description  =>  'new parent',
          context_id   => v_context_id);
	  
      dbms_output.put_line ('Counting project creation ');

      select count(*) into p_count
      from pt_projects;

      utAssert.eq (
          msg_in          => 'Creating new project counting project_id',
	  check_this_in   => p_count,
	  against_this_in => 1);

      dbms_output.put_line ('Counting task creation ');
      -- Check for root node creation in pt_task

      select count(*) into p_count
      from pt_tasks;

      utAssert.eq (
          msg_in          => 'Creaing new project. counting tasks',
	  check_this_in   => p_count,
	  against_this_in => 1);

      -- Check for priority option creation

      select count(*) into p_count from pt_priorities
      where package_id = v_package_id;

      utAssert.eq (
          msg_in          => 'Creaing new project. counting priority options',
	  check_this_in   => p_count,
	  against_this_in => 3);
      
      dbms_output.put_line ('Done ');
      
    end;

    procedure new_with_id
    is
        v_project_id pt_projects.project_id%TYPE;
    begin

      v_project_id :=   pt_project.new (
          project_id   => -10000,
          package_id   => v_package_id,  
	  root_id      => -1000,
          name	       =>  'parent',
	  description  =>  'new parent',
          context_id   => v_context_id);
	
      utAssert.eq (
          msg_in          => 'Creating new project with id',
	  check_this_in   => v_count,
	  against_this_in => 2);

      select count(*) into v_count
      from pt_tasks;

      utAssert.eq (
          msg_in          => 'Creating new project',
	  check_this_in   => v_count,
	  against_this_in => 2);
    
    end new_with_id;

    procedure name 
    is
    v_project_id pt_projects.project_id%TYPE;
    v_root  pt_tasks.task_id%TYPE;
    v_child pt_tasks.task_id%TYPE;
    v_name  pt_tasks.name%TYPE;
    begin
        v_project_id :=   pt_project.new (
          package_id   => v_package_id,  
          name	       =>  'parent',
	  description  =>  'new parent',
          context_id   => v_context_id);

	v_root := pt_project.get_root (v_package_id );

        ut_pt_task.create_tree (v_root);

	select task_id into v_child
	from pt_tasks
	where name = 'grandchild';

	v_name := pt_project.name (v_child);

	utAssert.eq (
	    msg_in => 'Checking name function',
	    check_this_in => 'parent',
	    against_this_in => v_name);
    end;
    -- Missing unit test for drop and reactivate

    -- Container procedure
    procedure ut_pt_project
    is
    begin
      dbms_output.put_line ('new test');
      new;
      dbms_output.put_line ('Tearing down');
      ut_teardown;

    end;
    
    begin
    -- package_id and context_id are constants
    select package_id into v_package_id
    from apm_packages where rownum = 1;
    
    v_context_id := -1;
end ut_pt_project;
/
show errors

exec utplsql.test('pt_project', recompile_in => false);

