/* 

   Test for sorting task list. Populates the tree in different ways
   sql/pt-task-package.sql

   Requires utPL/SQL

   @author Nobuko Asakai (nasakai@arsdigita.com)
   @creation-date Apr 10 2001
   @cvs-id $Id: sort-test.sql,v 1.1.1.1 2001/04/10 21:00:12 nasakai Exp $
   
*/


/*
Run this query
    
   column  name  format a30;

    select name
    from pt_tasks
    start with parent_id is null
    connect by parent_id = prior task_id;
*/

create or replace package ut_pt_tree
is
    procedure small_tree;
    procedure medium_tree;
    procedure ut_teardown;
    procedure ut_setup;
end;
/
show errors


create or replace package body ut_pt_tree
is
    
    procedure small_tree
    is
       v_task_id	pt_tasks.task_id%TYPE;
       v_parent_id	pt_tasks.task_id%TYPE;
    begin

    -- The point of this is to create a tree where names are not in order
        /*
	    P
	    - c "Orange"
	    -- g
	    -- g2
	    - c  "Apple"
	    */

     	 v_parent_id :=  pt_task.new (	
	      parent_id		  => null,
	      name		  => 'parent',
              description	  => 'Parent task',
	      context_id	  => -1
         );

     	 v_task_id :=  pt_task.new (	
	      parent_id		  => v_parent_id,
	      name		  => 'Orange',
              description	  => 'Parent task',
	      context_id	  => -1
         );

     	 v_task_id :=  pt_task.new (	
	      parent_id		  => v_parent_id,
	      name		  => 'Apple',
              description	  => 'Parent task',
	      context_id	  => -1
         );

    end;

    procedure medium_tree
    is
       v_task_id	pt_tasks.task_id%TYPE;	
       v_parent_id	pt_tasks.task_id%TYPE;	
       v_root_id	pt_tasks.task_id%TYPE;	
    begin		

	ut_teardown;
        /*
	    Sort of branch depends on children

	    P
	    - c "abc"
	    -- g "Orange"
	    - c  "abc"
	    -- g2 "Apple"

	    */

     	 v_root_id :=  pt_task.new (	
	      parent_id		  => null,
	      name		  => 'parent',
              description	  => 'Parent task',
	      context_id	  => -1
         );

     	 v_parent_id :=  pt_task.new (	
	      parent_id		  => v_root_id,
	      name		  => 'abc',
              description	  => 'Parent task',
	      context_id	  => -1
         );

     	 v_task_id :=  pt_task.new (	
	      parent_id		  => v_parent_id,
	      name		  => 'Orange',
              description	  => 'Parent task',
	      context_id	  => -1
         );


     	 v_parent_id :=  pt_task.new (	
	      parent_id		  => v_root_id,
	      name		  => 'abc',
              description	  => 'Parent task',
	      context_id	  => -1
         );

     	 v_task_id :=  pt_task.new (	
	      parent_id		  => v_parent_id,
	      name		  => 'Apple',
              description	  => 'Parent task',
	      context_id	  => -1
         );

    end;

    procedure ut_teardown
    is
    begin
        ut_pt_task.ut_teardown;
    end;

    procedure ut_setup
    is
    begin
        null;
    end;
end;
/
show errors

