# /packages/project-tracker/www/admin/index.tcl

ad_page_contract {
    Present a list of all parties for user to select the notification sender.
    Slightly modified from ticket-tracker sender-designate page. Since
    project-tracker doesn't have other parameters to set at the
    moment, this is the index page

    @author Nobuko Asakai (nasakai@arsdigita.com)
    @creation-date 2001-02-28
    @cvs-id $Id: index.tcl,v 1.2 2001/04/13 17:29:55 nasakai Exp $
    
    @param priority_id The id for the priority being edited
    @action_type one of sender_designate priority_ae
} {
    {action_type ""}
    {v_priority_id ""}
} -properties {
    context_bar:onevalue
    party:multirow
    designated_sender:onerow
    project:onerow
}

set user_id [ad_maybe_redirect_for_registration]
set package_id [ad_conn package_id]
ad_require_permission $package_id "admin"
set context_bar {}

db_1row get_root " 
select pt_project.get_root(:package_id) as root_id
from dual"

if {![exists_and_not_null root_id]} {
    # redirect to the initialization page
    ad_returnredirect "initialize"
    return
}

set initialized_p [db_0or1row project_select {
    select name, 
           description, 
           html_p
    from pt_tasks
    where task_id = :root_id
} -column_array {project} ]

# current designated sender
db_1row sender_select {
      select p.party_id,
             acs_object.name(p.party_id) as name,
             email
        from parties p
        where pt_util.notification_sender(:package_id) =  p.party_id
} -column_array {designated_sender} 

# Different: we only get users with admin permissions

set designate_link "<a href=index?[export_vars {{action_type "sender_designate"}}]>Change</a>"

form::create sender_designate \
	-action "sender-designate-2"

if {[string equal $action_type "sender_designate"]} {

    # Generating list for the form widget

    # We disallow parties that do not have an email address, but we
    # also want to expand the groups to get the users belonging to a group.

    # Technically groups could have a group email address however,
    # while the datamodel and the API support adding
    # email address to a group,  the UI doesn't, so we are not so concerned.
    # nasakai@arsdigita.com April 12 2001

    set possible_parties [db_list_of_lists parties_select {
	select distinct acs_object.name(u.user_id) as name,
        u.user_id, p.email
	from acs_object_party_privilege_map appm, 
	     parties p,
	     party_approved_member_map pamm,
	     users u 
	where appm.object_id = :package_id
        and appm.privilege = 'admin'
	and appm.party_id <> 0
	and pamm.party_id = appm.party_id
	and pamm.member_id = u.user_id
	and u.user_id = p.party_id
	order by name
    }] 

	
   template::element create sender_designate "party_id" \
		-datatype integer \
		-widget select \
		-options "$possible_parties"


   template::element set_properties sender_designate "party_id" \
	       -value $designated_sender(party_id)

	
}
ad_return_template












