# packages/project-tracker/www/admin/initialize.tcl

ad_page_contract {

    Initialization page for starting project-tracker. Checks to see if
    workflow and general comments are mounted. If everything is ok,
    returns the form for starting the project.

    @author Nobuko Asakai (nasakai@arsdigita.com)
    @creation-date Mar 02 2001
    @cvs-id $Id: initialize.tcl,v 1.1.1.1 2001/04/10 21:00:11 nasakai Exp $
} -properties {
    context_bar:onevalue
    workflow_mounted_p:onevalue
    task_id
}

set user_id [ad_maybe_redirect_for_registration]
set package_id [ad_conn package_id]
ad_require_permission $package_id "admin"

# You shouldn't be able to get to this page if you have already
# initialized the project.

db_0or1row get_root { 
    select pt_project.get_root(:package_id) as root_id
    from dual
}

if {[exists_and_not_null root_id]} {
    # redirect to the install directory
    ad_returnredirect index
    return
}

set context_bar {}

# check to see if general comments has been mounted
db_1row check_gc {
    select count(*) as gc_mounted_p
      from site_nodes sn,
           apm_packages ap
     where ap.package_key = 'general-comments'
       and sn.object_id = ap.package_id
}

db_1row check_workflow {
    select count(*) as workflow_mounted_p
      from site_nodes sn,
           apm_packages ap
     where ap.package_key = 'acs-workflow'
       and sn.object_id = ap.package_id
}

# check to see if SystemUrl still has its default value
if { ![db_0or1row dubious_sys_url {
      select apv.attr_value as dubious_url
          from apm_parameter_values apv,
               apm_parameters ap
         where ap.package_key = 'acs-kernel'
           and ap.parameter_name = 'SystemURL'
           and ap.parameter_id = apv.parameter_id
    and ap.default_value = apv.attr_value
}] } {
    set dubious_url ""
}

form::create project_add \
	-action "initialize-2"

if { !$gc_mounted_p || !$workflow_mounted_p || ![empty_string_p $dubious_url] } {
    set has_error_p 1
} else {
    set has_error_p 0
    
    # create template for tasks

    template::element create project_add task_id \
	    -widget hidden \
	    -value [db_nextval acs_object_id_seq]
    

    template::element create project_add name \
	    -widget text \
	    -label Name

    template::element create project_add description \
	    -widget textarea \
	    -label Description \
	    -html {columns 15 rows 5 wrap soft}

    template::element create project_add html_p \
	    -datatype string \
	    -widget select \
	    -label "&nbsp;" \
	    -value  t \
	    -options {
	{HTML t}
	{"Plain text" f}
    }
	 
}

ad_return_template
















