# project-tracker/www/admin/priority-ae.tcl

ad_page_contract { 
    @author Nobuko Asakai (nasakai@arsdigita.com)
    @creation-date 2001-04-09
    @cvs-id $Id: priority-ae.tcl,v 1.2 2001/04/10 22:37:36 nasakai Exp $
    
    @param priority_id The id for the priority being edited
    @action_type one of sender_designate priority_ae
} {
    v_priority_id:notnull,integer
    name:nohtml,notnull
    value:integer,notnull
    action_type:notnull,nohtml
    return_url:notnull
} -validate {

    priority_id_is_valid  -requires { v_priority_id:notnull } {
	if {[string equal $action_type "priority_edit"]} {

	    # If we are editing, we want to make sure that it is a valid
	    # priority  ie. right package_instance.  
	    set package_id [ad_conn package_id]
	    
	    db_1row package_priority_id_check {
		select count(*) as valid_p
		from pt_priorities
		where package_id = :package_id
		and priority_id = :v_priority_id
		
	    }
	
	    if {!$valid_p} {
		ad_complain "$priority_id is not a valid priority for
		package instance $package_id"
	    }
	}
    }
    
    name_is_duplicate -requires { v_priority_id:notnull name:notnull } {
	# If it is a new priority, we want to make sure that is not a
	# duplicate, actually we need to do this for everything
	set package_id [ad_conn package_id]

	if {[db_0or1row duplicate_check {
	    select name as d_name, value as d_value, priority_id
	    from pt_priorities
	    where package_id = :package_id
	    and name = :name
	    and priority_id <> :v_priority_id
	}] } {
	    ad_complain "The name \"$name\" 
	    is already used by the option $d_name, $d_value with ID $priority_id" 
	}

    }
    
    value_is_duplicate -requires { v_priority_id:notnull value:integer } { 

	set package_id [ad_conn package_id]
	
	if {[db_0or1row duplicate_check {
	    select value as d_value, name as d_name, priority_id
	    from pt_priorities
	    where package_id = :package_id
	    and priority_id <> :v_priority_id
	    and value = :value	    
	}]} {
	    ad_complain "The value \"$value\"
	    is already used by option called $d_name, $d_value with ID $priority_id"
	}

    }

}


set package_id [ad_conn package_id]

ad_require_permission $package_id "write"

db_transaction {
    db_dml priority_option_update {
	update pt_priorities
	set name = :name,
	value = :value
	where priority_id = :v_priority_id
	and package_id = :package_id
    }

    if {![db_resultrows]} {
	set tempval [db_exec_plsql pt_priority_new {
	    begin
	    :1 := pt_priority.option_new (
	          priority_id  => :v_priority_id,
	          package_id   => :package_id,
	          name         => :name,
       	          value        => :value
	    );
	    end;
	}]
    }
}

ad_returnredirect $return_url


