# /packages/project-tracker/www/state-change.tcl

ad_page_contract {
    Changes the state of a workflow case. Almost exactly like ticket-tracker change-state.

    @author Tony Tseng (tony@arsdigita.com) Nobuko Asakai (nasakai@arsdigita.com)
    @creation-date 2001-2-27
    @cvs-id $Id: state-change.tcl,v 1.2 2001/04/18 00:35:30 nasakai Exp $
} {
    case_id:integer,notnull
    action:notnull
    {return_url "index"}
}

set package_id [ad_conn package_id]
ad_require_permission $package_id write
ad_maybe_redirect_for_registration

# get the state 
db_1row case_state_select {
    select state 
    from wf_cases
    where case_id = :case_id
}

set error_p 0

switch $action {
    suspend {
        if {[string equal $state "active"]} {
            wf_case_suspend -msg "Suspended in PT" $case_id
        } else {
	    incr error_p
	    set err_msg "The task is in state \"$state\". The state must be \"active\" for \"$action\"."
	}
    }
    resume {
        if { [string equal $state "suspended"] || \
		[string equal $state "canceled"] } {
            wf_case_resume -msg "Resumed in PT" $case_id
        } else {
	    incr error_p
	    set err_msg "The task is in state \"$state\". The state must be \"suspended\" or \"canceled\" for \"$action\"."
	}
    }
}

if {$error_p} {
    ad_return_complaint $error_p $err_msg
} else {
    ad_returnredirect $return_url
}


