# /packages/project-tracker/www/task-action.tcl

ad_page_contract {
    Tells the workflow engine that a given action has been taken

    PT uses this page to start and cancel wf tasks.

    @author Tony Tseng (tony@arsdigita.com) Nobuko Asakai (nasakai@arsdigita.com)
    @creation-date 2001-2-27
    @cvs-id $Id: task-action.tcl,v 1.2 2001/04/18 00:35:30 nasakai Exp $
} {
    action:notnull
    wf_task_id:notnull,integer
    msg:optional,nohtml
    return_url:notnull
} -validate {
    action_is_valid -requires {action:notnull} { 
	if {[string equal action "start"] || \
		[string equal action "cancel"] || \
		[string equal action "finish"] } {
	    
	    ad_complain "$action is not a valid action"
	}
    }
}

set package_id [ad_conn package_id]

set user_id [ad_maybe_redirect_for_registration]

set msg ""

# Confirm that the user is indeed assigned to the task

# We want to allow the admin to change the state, without changing the
# assignments

# If the user is an administrator they can cancel tasks that don't
# belong to them


ad_require_permission $package_id "write"

set error_p 0

db_transaction {
    set task_exists [db_0or1row action_state_check {
	select wt.state wt_state, 
	       holding_user,
	       wc.state as wc_state,
	acs_object.name(:user_id) as user_name
	from wf_tasks wt, wf_cases wc
	where task_id = :wf_task_id
	and wt.case_id = wc.case_id
    }]
	
    if {!$task_exists} {
	    incr error_p
	set msg "$wf_task_id is not a valid task_id"
    } elseif {![string equal $wc_state "active"]} {
	# We also want to make sure that the case isn't canceled or
	# suspended. The only allowable state is "active"
	incr error_p
	set err_msg "This task is in state \"$wc_state\", the state must be \"active\" for action \"$action\""
    } else {
	
	# Allowable task state and action combination
	# start -> enabled
	# cancel -> started
	# finish -> started
	
	switch $action {
	    start {
		if {![string equal $wt_state "enabled"]} {
		    incr error_p
		    set err_msg "Task must be in \"enabled\" state for action \"$action\". It is currently in \"$wt_state\" state"
		} else {
		    set msg "Task started in PT"
		}
	    } cancel {
		if {![string equal $wt_state "started"]} {
		    incr error_p
		    set err_msg "Task must be in  \"started\" state for action \"$action\". It is currently in \"$wt_state \" state"		    
		} else {
		    set msg "Task canceled in PT"
		}
	    } 
	}
    }
    if {$error_p} {
	ad_return_complaint $error_p $err_msg
    } else {
	wf_task_action -user_id $user_id \
		-msg $msg \
		$wf_task_id $action
    }

}

ad_returnredirect $return_url











