# /packages/project-tracker/www/task-assign.tcl

ad_page_contract {
    For setting assignments. Both removing and adding.

    @author Nobuko Asakai (nasakai@arsdigita.com)
    @creation-date Feb 24 2001
    @cvs-id $Id: task-assign.tcl,v 1.2 2001/04/17 20:19:08 nasakai Exp $
} { 
    v_task_id:notnull,integer,pt_task_id
    party_id:notnull,integer
    assigned_p:notnull,nohtml
    {return_url index}
} -validate {
    task_is_not_dead -requires v_task_id:notnull {

	# Note: This is not a complete check as it only checks for
	# dropped and not for finished..
	set dropped_p [db_exec_plsql active_check {
	    begin
	    :1:= pt_task.is_dropped (:v_task_id);
	    end;
	}]
	if {[string equal $dropped_p "y"]} {
		ad_complain "You cannot change assignments for dropped tasks."
	}
    }

    party_id_is_not_zero -requires party_id:notnull {

	 # We further ensure that party_id is not magic object root
	 # security context, 0
	if {[string equal $party_id 0]} {
	    ad_complain "You cannot assign the root context to a task."
	}
    }

    party_id_is_general_public -requires party_id:notnull {

	 # We further ensure that party_id is not the general public
	if {[string equal $party_id -1]} {
	    ad_complain "You cannot assign the general public to a task"
	}
    }
}


# Don't forget to check for duplicates in assignments before insert,
# though this should not be possible if the UI stays the same

ad_require_permission [ad_conn package_id] "write"
ad_maybe_redirect_for_registration

if {[string equal $assigned_p "f"]} {
    # Double click protection
    db_transaction {
	if {![db_0or1row doble_click_check {
	    select 1 
	    from wf_case_assignments wca,
	    wf_cases wc
	    where wc.object_id = :v_task_id
	    and wca.transition_key = 'complete'
	    and wca.case_id = wc.case_id
	    and wca.party_id = :party_id
	}]} {

	    db_exec_plsql assign_task {
		begin
		pt_task.assign_task (
		task_id  => :v_task_id,
		party_id => :party_id
		);
		end;
	    }
	}
    }
} else {

    # Unassigning a task

    # Double click protection
    db_transaction {
	db_0or1row doble_click_check {
	    select wc.case_id, 
                   decode(wt.task_id, NULL, 'f', 't') as holding_user_p,
	           wt.task_id as wf_task_id
	    from wf_case_assignments wca, 
	         wf_cases wc,
	         (select task_id, case_id
	          from wf_tasks
	          where state = 'started'
	          and holding_user = :party_id) wt
	    where wc.object_id = :v_task_id
	    and   wca.transition_key = 'complete'
	    and   wca.case_id = wc.case_id
	    and   wca.party_id = :party_id
	    and wc.case_id = wt.case_id (+)
	}

	if {[exists_and_not_null case_id]} {
	    # Double click protection
	    if {[string equal $holding_user_p "t"]} {

		# We revert the holding user if the task's holding
		# user is being unassigned

		wf_task_action -user_id $party_id \
			-msg "Holding user has been unassigned in PT" \
			$wf_task_id "cancel"
	    }

	    db_exec_plsql unassign_task {
		begin
		pt_task.unassign_task (
		task_id  => :v_task_id,
		party_id => :party_id
		);
		end;
	    }
	    

	}   
    }
}

ad_returnredirect $return_url






