# /packages/project-tracker/www/task-drop.tcl

ad_page_contract {
    Drop, delete, or reactivates tasks 
    You cannot move or delete the root tasks

    @author Nobuko Asakai (nasakai@arsdigita.com)
    @creation-date Feb 24 2001
    @cvs-id $Id: task-drop.tcl,v 1.1.1.1 2001/04/10 21:00:10 nasakai Exp $

    @param action_type Possible values are drop delete and reactivate
} { 
    v_task_id:integer,notnull
    action_type:nohtml,notnull
    return_url:notnull
} -validate {
    valid_action_type  -requires action_type:notnull {
	if {![string equal $action_type drop] && \
		![string equal $action_type reactivate] && \
		![string equal $action_type delete] } {
		ad_complain "$action_type is not a valid request"
	}
    }
    
    valid_task_id {

	# We don't check task_id validity for deleting because
	# it could be a double click, in which case the task would not
	# exist
	
	if {[string equal $action_type drop] && \
		[string equal $action_type reactivate] } {
	} {
	    set package_id [ad_conn package_id]
	    
	    db_1row valid_task_id {
		select 
		pt_project.task_valid_p(:package_id, :v_task_id) as valid_p
		from dual
	    }
	    if {!$valid_p} {
		ad_complain "$v_task_id is invalid"
	    }
	}
    }
}


# If it's drop or reactivate the task_id has to be valid

set user_id [ad_maybe_redirect_for_registration]
set package_id [ad_conn package_id]
set peeraddr [ad_conn peeraddr]

ad_require_permission $package_id "admin"

# Double click protection, for drop and reactivate we 

ns_log notice "v_task_id is $v_task_id"

db_transaction {
    set exists_p [db_0or1row dropped_p {
	select dropped_p
	from pt_tasks
    where task_id = :v_task_id
    }]
	
	
    set dml_ok "f"
	
	switch $action_type {
	    drop {
		set  procedure_call pt_task.drop_task
		if {[string equal $dropped_p f]} {
		    set dml_ok t
		}
	    } reactivate {
		set  procedure_call pt_task.reactivate_task
		if {[string equal $dropped_p t]} {
		    set dml_ok t
		}
	    } delete {
		set  procedure_call pt_task.delete
		if {$exists_p} {
		    set dml_ok t
		}
	    } 
	}

	if {[string equal $dml_ok "t"]} {
	    
	    db_exec_plsql task_drop "
	    begin
	    $procedure_call (
	    task_id       => :v_task_id,
	    context_id    => :package_id,
	    creation_user => :user_id,
	    creation_ip   => :peeraddr
	    );
	    end;
	    "
	}
}

ad_returnredirect $return_url










