# packages/project-tracker/www/task-view.tcl

ad_page_contract {
    Detailed view for a task in project-tracker

    @author Nobuko Asakai (nasakai@arsdigita.com)
    @creation-date Feb 24 2001
    @cvs-id $Id: task-view.tcl,v 1.4 2001/04/18 00:35:30 nasakai Exp $

    @pram action_type possible action types are edit and assign
} {
    v_task_id:trim,integer,pt_task_id
    {action_type ""}
    {search_keyword:nohtml ""}
} -properties {
    pt_task
    children
    page_title
    context_bar
    wf_url
}

set user_id [ad_maybe_redirect_for_registration]
set package_id [ad_conn package_id]
ad_require_permission $package_id "write"
set admin_p [ad_permission_p -user_id $user_id $package_id "admin"]

db_1row top_info {
    select name, leaf_p, pt_util.workflow_url('f') as wf_url
    from pt_tasks
    where task_id = :v_task_id
} -column_array top_info


# Master template properties
set page_title "$top_info(name)"
set wf_link "\n<a href=$top_info(wf_url)>My workflow task list\n"

get_ancestors -var_to_export v_task_id -current_task {$name} $v_task_id

# Stuff to make the page "sticky" return_url handlers

set return_url "[ad_conn package_url]task-view?[export_vars -override \
	{{action_type ""}} {action_type v_task_id}]"

set edit_link "<a href=task-view?[export_vars -override \
	{{v_task_id $v_task_id} \
	{action_type edit}} {action_type v_task_id}]>Edit</a>"

# You always get the comment and edit options, these links are
# slightly different from the wf links in index.tcl

# change this to foreach 


db_multirow pt_task task_info_select {
    select pt.task_id,
           pt.parent_id,
           pt.name, 
           pt.description,  
           pt.estimated_days,  
           pt.actual_days,
           to_char(pt.deadline, 'YYYY/Mon/DD') as deadline,
           (trunc(sysdate) - trunc(pt.deadline)) as days_late,
           pt.parent_id,
           pt.leaf_p,
           pt.html_p,
           pt.dropped_p,
           wt.holding_user as holding_user,
           nvl2(mine.case_id, 't', 'f') as mine_p,
           decode(holding_user, :user_id, 't', 'f') as holding_user_p,
           pt_priority.option_name(priority) as priority,
           pt_project.name(:v_task_id) as project_name,
           wc.state,
           wc.case_id,
           nvl(decode(dropped_p, 't', 'dropped', wc.state),
               decode(leaf_p, 'f', 'parent task', '')) as state,
           acs_object.name(wca.party_id) as assignee_name,
           p.email,
           wt.task_id as wf_task_id,
           wt.state as wt_state,
           to_char(wt.started_date, 'Mon/DD/YYYY') as started_date,
           p.party_id,
           pt_util.workflow_url('f') as wf_url,
           pt_project.get_root(:package_id) as root_id,
           '' as admin_options,
           '' as assignmnet_link,
           '' as workflow_link 
    from pt_tasks pt, wf_cases wc, 
         (select * from wf_tasks 
          where state = 'enabled' or state = 'started' or state = 'finished')  wt, 
         (select case_id 
          from pt_case_assignments
          where user_id = :user_id
          ) mine,
          wf_case_assignments wca, parties p
    where pt.task_id = :v_task_id
    and pt.task_id = wc.object_id(+)
    and wc.case_id = wca.case_id(+)
    and wc.case_id = wt.case_id(+)
    and wc.case_id = mine.case_id(+)
    and wca.party_id = p.party_id(+)
} {
    if {$admin_p} {
	set admin_options "
	[drop_option \
		-root_id $root_id \
		-return_url $return_url \
		$dropped_p \
	    $v_task_id]\n"
    } else {
	set admin_options ""
    }
    
    if {[string equal $dropped_p "f"] && [string equal $leaf_p "t"] } {
	set assignment_link [assignment_option \
		-state $state \
		$v_task_id]
	
	set workflow_link  [workflow_link -wf_url $wf_url \
		-party_id $party_id \
		-wf_task_id $wf_task_id \
		-case_id $case_id \
		-wt_state $wt_state \
		-started_date $started_date \
		-return_url $return_url \
		-mine_p $mine_p \
		-holding_user_p $holding_user_p \
		-admin_p $admin_p \
		$state $v_task_id]

    } elseif {[string equal $dropped_p "t"]} {
	set workflow_link "<em>Dropped</em>"
	set assignment_options ""
    } elseif {[string equal $leaf_p "f"]} {
	set workflow_link "<em>Parent task</em>"
	set assignment_options ""
    } {
	set workflow_link ""
	set assignment_options ""
    }
}

# We do not have an add option here so it's safe to assume that we
# have values for everything

# We don't worry about the insert because another page is going to do
# it for us

set form_name "task_edit"

form::create $form_name \
	-action "task-ae" \
	-html "bgcolor #CCCCFF"

if [string equal $action_type "edit"] {
    # Grey out the edit link
    set edit_link "<font color=gray>Edit</font>"
    # Parents don't get deadlines
    
    task_ae_form -v_task_id $v_task_id \
	    -leaf_p $top_info(leaf_p) \
	    $form_name $return_url 
}


db_multirow child_tasks children_query {
    select task_id, name,
    '' as name_link
    from pt_tasks
    where parent_id = :v_task_id
} {
    set name_link "
    <a href=[ad_conn url]?[export_vars {{v_task_id $task_id}}]>$name</a>"
}

# For the options we want to say, write [edit, comment assign start
# cancel, resume, suspend]  admin [drop reactivate]

set context_bar {""}

## General comments
# We don't use workflow_journal because cases are created and deleted.

set comment_link [general_comments_create_link -context_id $package_id \
	$v_task_id "$return_url"]

set comments [general_comments_get_comments -print_content_p 1 "$v_task_id" \
	"$return_url"]
if {[empty_string_p $comments]} {
    set comments "<em>no comments</em>"
}

ad_return_template
























