# project-tracker/www/user-search.tcl

# panel, expects v_task_id, search_keyword

set action_type "assign"

set package_id [ad_conn package_id]
set extra_where ""
set search_again ""

## The parameter values for switching assignment method

set select_threshold [ad_parameter PTAssignmentDropdownThreshold]

# We make sure that these values exist
if {![exists_and_not_null select_threshold]} {
    set select_threshold 10
}

set search_threshold [ad_parameter PTAssignmentSearchThreshold]

if {![exists_and_not_null search_threshold]} {
    set search_threshold 50
}


if {[exists_and_not_null search_keyword]} {

    # We just executed the search

    set sql_keyword "%[string tolower $search_keyword]%"
    set extra_where "and lower(acs_object.name(party_id)) like :sql_keyword"
    set search_result "t"
    
    set search_again "
    <p>
    (<a href=[ad_conn url]?[export_vars {{action_type assign} v_task_id}]#${v_task_id}>search again</a>)
    </p>\n"

} else {
    set search_result "f"
}


# ids 0 and -1 are not allowed
# We are generating the template multirow data source
set possible_parties [list ]

template::multirow create unassigned_parties name party_id assignment_link

set unassigned_parties_query "
select party_id, acs_object.name(pm.party_id) as name, party_id
from acs_object_party_privilege_map pm
where  object_id = :package_id
and pm.privilege = 'write'
and party_id <> 0
and party_id <> -1
$extra_where
and not exists (select 1
                from wf_case_assignments wca, wf_cases wc
                where wc.object_id = :v_task_id
                and wc.case_id = wca.case_id
                and pm.party_id = wca.party_id)
order by lower(acs_object.name(pm.party_id))
"
# i is the rowcount
set i 0

db_foreach unassigned_parties_select $unassigned_parties_query  {

    set assignment_link "<a href=task-assign?[export_vars \
	    -override {{party_id $party_id} \
	    {v_task_id $v_task_id} {assigned_p "f"}} \
	    {party_id v_task_id assigned_p return_url}]>$name</a>"

    template::multirow append unassigned_parties $name $party_id $assignment_link
    
    # We also generate a tcl_list for making the select widget
    lappend possible_parties [list $name $party_id]

    incr i
}

# What kind of form we create depends on the number of rows
set form_name "link_list"
set action "link_list"


# We need to have the search box again for search_result

if {![string equal $search_result "t"]} {
    if {[expr { $i >= $search_threshold }] } {
	# More than 50, search
	set form_name "party_search"
	set action $return_url
    } elseif {[expr { $i >= $select_threshold }] } {
	set form_name "party_select"
	set action task-assign
	# More than 10, drop down
    }
}

form::create $form_name \
	-action $action

    template::element create $form_name v_task_id \
	    -widget hidden \
	    -value $v_task_id



if {[ string equal $form_name "party_search"] } {

    # Action type informs the index page that we are still in assign
    # mode

    template::element create $form_name action_type \
	    -widget hidden \
	    -value assign

    template::element create $form_name search_keyword \
	    -widget text \
	    -label "keyword"

} elseif {[string equal $form_name "party_select"] } {
    template::element create $form_name assigned_p \
	    -widget hidden \
	    -value f

   template::element create $form_name party_id \
	   -widget select \
	   -options "$possible_parties"

    template::element create $form_name return_url \
	    -widget hidden \
	    -value $return_url 

}

ad_return_template unassigned-parties










